@@ -15,8 +15,9 @@ from uadm.uadmcore import *
 if __name__ == '__main__':
 
     mod_conf({
-        'UADM_PAM_SCRIPT_USE_CENTRIFY' : False,
+        'UADM_USE_CENTRIFY' : False,
         'UADM_PAM_SCRIPT_CENTRIFY_ADMINGROUP' : "Domain Admins",
+        'UADM_AUTO_MOUNT_DIR' : "/usr/local/bin/auto_mount_www",
     }, override=False)
 
     mod_conf({
@@ -27,7 +28,7 @@ if __name__ == '__main__':
     pam_user = os.getenv('PAM_USER')
 
     cmd_list = ['bash -c \'id %s | grep "27(sudo)\|0(root)"  2> /dev/null\'' % pam_user]
-    if CONF_MAP['UADM_PAM_SCRIPT_USE_CENTRIFY']:
+    if CONF_MAP['UADM_USE_CENTRIFY']:
         cmd_list.append('bash -c \'adquery user %s -A 2> /dev/null | grep "%s"\'' % (pam_user, admin_group))
 
     is_admin = False
@@ -40,7 +41,8 @@ if __name__ == '__main__':
         cmd_list = [
             'mkdir -p /home/%(user)s' % {'user':pam_user},
             'chown root:%(user)s /home/%(user)s' % {'user':pam_user},
-            'run-parts --report --arg="mount" /usr/local/bin/auto_mount_www/',
+            'chmod g+rx /home/%(user)s' % {'user':pam_user},
+            'run-parts --report --arg="mount" %s' % CONF_MAP['UADM_AUTO_MOUNT_DIR'],
         ]
         exec_cmd_list(cmd_list)
 
